@@ -751,15 +751,7 @@ class RfAggregationGroup(BaseWrapperClass):
     @tx_interference_signal_ratio.setter
     def tx_interference_signal_ratio(self, value):
         if value is not None:
-            if value >= -150 and value <= 150:
-                self.pb.tx_interference_signal_ratio = value
-            elif self.errctx:
-                self.errctx.add(
-                    network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
-                    'Invalid value for NetworkElement.RfAggregationGroup.tx_interference_signal_ratio',
-                    value=value,
-                    metric_name=
-                    'NetworkElement.RfAggregationGroup.tx_interference_signal_ratio')
+            self.pb.tx_interference_signal_ratio = value
         else:
             self.pb.ClearField('tx_interference_signal_ratio')
 
@@ -771,15 +763,7 @@ class RfAggregationGroup(BaseWrapperClass):
     @rx_interference_signal_ratio.setter
     def rx_interference_signal_ratio(self, value):
         if value is not None:
-            if value >= -150 and value <= 150:
-                self.pb.rx_interference_signal_ratio = value
-            elif self.errctx:
-                self.errctx.add(
-                    network_poller_pb2.PollError.ERROR_BAD_DATA_RANGE,
-                    'Invalid value for NetworkElement.RfAggregationGroup.rx_interference_signal_ratio',
-                    value=value,
-                    metric_name=
-                    'NetworkElement.RfAggregationGroup.rx_interference_signal_ratio')
+            self.pb.rx_interference_signal_ratio = value
         else:
             self.pb.ClearField('rx_interference_signal_ratio')
 
