@@ -49,6 +49,12 @@ async def ping(host):
         logging.warning('%s error pinging host %s: %s', type(err).__name__, host, err)
 
 
+STANDARD_PORT_METHOD = {
+    80: 'http',
+    443: 'https',
+}
+
+
 async def http_probe(host,
                      http_client_cls,
                      methods=('https', 'http'),
@@ -61,18 +67,25 @@ async def http_probe(host,
     """
 
     async def handler(response):
+        """
+        Handler to process the HTTP response.
+        Returns True if a valid response is detected.
+        """
         if 200 <= response.status <= 400:  # accept a redirect, its listening.
             if response.status == 302 and response.request_info.url.scheme == 'http':
                 loc = response.headers.get('location')
-                if loc and loc.startswith('https'):
+                if loc and loc.startswith(
+                        'https'):  # redirect to https, don't return http
                     return False
             return True
         return False
 
+    # Build URLs to probe.
     urls = [
-        f'{m}://{host}{":" if port else ""}{port}' for m in methods
-        for port in ports or ['']
+        f"{method}://{host}{f':{port}' if port and STANDARD_PORT_METHOD.get(port) != method else ''}"
+        for method in methods for port in ports or [None]
     ]
+
     clients = [
         http_client_cls(url,
                         verify_ssl=False,
@@ -83,19 +96,20 @@ async def http_probe(host,
     ]
     result = None
     try:
-        for i, r in enumerate(await asyncio.gather(*[
-                x.request('', num_retries=0, allow_redirects=False, handler=handler)
-                for x in clients
+        responses = await asyncio.gather(*[
+            client.request('', num_retries=0, allow_redirects=False, handler=handler)
+            for client in clients
         ],
-                                                   return_exceptions=True)):
-            if r and not result and not isinstance(r, Exception):
-                result = clients[i]
-            else:
-                await clients[i].close()
+                                         return_exceptions=True)
+        for client, response in zip(clients, responses):
+            if response is True and not result:  # valid response and result not yet set
+                result = client
     except asyncio.CancelledError:
-        # If the gather operation is cancelled, we have to clean up here.
-        [await x.close() for x in clients]
+        result = None  # we are cancelled; let the finally clause clean up
         raise
+    finally:
+        await asyncio.gather(
+            *[client.close() for client in clients if client is not result])
     return result
 
 
@@ -476,6 +490,16 @@ async def _mikrotik_probe(host,
                         return client
                 except (MikrotikApiError, OSError, asyncio.TimeoutError) as err:
                     pass
+        except asyncio.CancelledError:
+            # PPA-1020 If this coroutine gets cancelled, it can mean one of two things.
+            # 1. We've been cancelled by mikrotik_api_probe because it already got
+            #    a successful probe result.
+            # 2. The overall probe for the element has been cancelled.  In that case,
+            #    it's important for the caller (mikrotik_api_probe) to get the
+            #    cancellation, so we do this eventloop yield to make sure we don't
+            #    process the cancellation and return before it can handle it.
+            await asyncio.sleep(0)
+            last_err = None
         finally:
             if not client:
                 await mikrotik_api.close()
@@ -505,6 +529,7 @@ async def mikrotik_api_probe(host,
             try:
                 result = task.result()
             except asyncio.CancelledError:
+                # The entire probe operation is cancelled.  Clean up all probes.
                 [x.cancel() for x in done]
                 [x.cancel() for x in pend]
                 raise
@@ -520,11 +545,15 @@ async def mikrotik_api_probe(host,
         if client:
             while pend:
                 task = pend.pop()
+                # PPA-1020 cancel the probe task and do not do an "await" to wait for
+                # it to clean up and complete.  This is important: if we await on the
+                # task and _this_ coroutine gets cancelled, the CancelledError only
+                # gets caught by the probe task and it suppresses it, and we lose the
+                # cancellation which is bad.  Instead, we've made sure the probe does
+                # its cleanup independently and does not need to be waited on here.
+                # This goes against general asyncio best practices, but seems to be a
+                # reliable way to make this work in all cases.
                 task.cancel()
-                try:
-                    await task  # let the task cleanup
-                except asyncio.CancelledError:
-                    pass
     return client
 
 
@@ -558,12 +587,17 @@ async def _ssh_probe(host, port, ssh_client_cls, creds, raise_errors, **kwargs):
     return client
 
 
-async def ssh_probe(host, ssh_client_cls, creds, raise_errors=False, **kwargs):
+async def ssh_probe(host,
+                    ssh_client_cls,
+                    creds,
+                    port=None,
+                    raise_errors=False,
+                    **kwargs):
     """Try to connect to a SSH server using list of (username, password) credentials."""
     # it's done this way to support multiple ports in the future
     pend = [
         asyncio.create_task(x) for x in
-        [_ssh_probe(host, None, ssh_client_cls, creds, raise_errors, **kwargs)]
+        [_ssh_probe(host, port, ssh_client_cls, creds, raise_errors, **kwargs)]
     ]
     client = None
     while pend:
