@@ -1309,10 +1309,10 @@ class TestNetworkElementUpdate(unittest.TestCase):
         rf_aggr_gr.tx_interference_signal_ratio = -20.59
         self.assertEqual(round(rf_aggr_gr.tx_interference_signal_ratio, 4), -20.59)
         rf_aggr_gr.tx_interference_signal_ratio = 190.59
-        self.assertEqual(round(rf_aggr_gr.tx_interference_signal_ratio, 4), -20.59)
+        self.assertEqual(round(rf_aggr_gr.tx_interference_signal_ratio, 4), 190.59)
         rf_aggr_gr.tx_interference_signal_ratio = None
         self.assertEqual(rf_aggr_gr.tx_interference_signal_ratio, None)
-        self.assertEqual(len(rf_aggr_gr.errctx.errors), 1)
+        self.assertEqual(len(rf_aggr_gr.errctx.errors), 0)
         rf_aggr_gr.errctx = None
 
         rf_aggr_gr.errctx = network_element_update.ErrorContext()
@@ -1320,10 +1320,10 @@ class TestNetworkElementUpdate(unittest.TestCase):
         rf_aggr_gr.rx_interference_signal_ratio = -20.59
         self.assertEqual(round(rf_aggr_gr.rx_interference_signal_ratio, 4), -20.59)
         rf_aggr_gr.rx_interference_signal_ratio = 190.59
-        self.assertEqual(round(rf_aggr_gr.rx_interference_signal_ratio, 4), -20.59)
+        self.assertEqual(round(rf_aggr_gr.rx_interference_signal_ratio, 4), 190.59)
         rf_aggr_gr.rx_interference_signal_ratio = None
         self.assertEqual(rf_aggr_gr.rx_interference_signal_ratio, None)
-        self.assertEqual(len(rf_aggr_gr.errctx.errors), 1)
+        self.assertEqual(len(rf_aggr_gr.errctx.errors), 0)
         rf_aggr_gr.errctx = None
 
         # Sector
